@@ -14,15 +14,19 @@ from social_auth.utils import sanitize_redirect
 DEFAULT_REDIRECT = getattr(settings, 'SOCIAL_AUTH_LOGIN_REDIRECT_URL', '') or \
                    getattr(settings, 'LOGIN_REDIRECT_URL', '')
 NEW_USER_REDIRECT = getattr(settings, 'SOCIAL_AUTH_NEW_USER_REDIRECT_URL', '')
+LOGIN_ERROR_URL = getattr(settings, 'LOGIN_ERROR_URL', settings.LOGIN_URL)
+COMPLETE_URL_NAME = getattr(settings, 'SOCIAL_AUTH_COMPLETE_URL_NAME',
+                            'complete')
+ASSOCIATE_URL_NAME = getattr(settings, 'SOCIAL_AUTH_ASSOCIATE_URL_NAME',
+                             'associate_complete')
 SOCIAL_AUTH_LAST_LOGIN = getattr(settings, 'SOCIAL_AUTH_LAST_LOGIN',
                                  'social_auth_last_login_backend')
+SESSION_EXPIRATION = getattr(settings, 'SOCIAL_AUTH_SESSION_EXPIRATION', True)
 
 
 def auth(request, backend):
     """Start authentication process"""
-    complete_url = getattr(settings, 'SOCIAL_AUTH_COMPLETE_URL_NAME',
-                           'complete')
-    return auth_process(request, backend, complete_url)
+    return auth_process(request, backend, COMPLETE_URL_NAME)
 
 
 @transaction.commit_on_success
@@ -48,14 +52,14 @@ def complete_process(request, backend):
 
     if user and getattr(user, 'is_active', True):
         login(request, user)
-        if getattr(settings, 'SOCIAL_AUTH_SESSION_EXPIRATION', True):
+        # user.social_user is the used UserSocialAuth instance defined
+        # in authenticate process
+        social_user = user.social_user
+
+        if SESSION_EXPIRATION :
             # Set session expiration date if present and not disabled by
             # setting. Use last social-auth instance for current provider,
             # users can associate several accounts with a same provider.
-            #
-            # user.social_user is the used UserSocialAuth instance defined
-            # in authenticate process
-            social_user = user.social_user
             if social_user.expiration_delta():
                 request.session.set_expiry(social_user.expiration_delta())
 
@@ -69,16 +73,14 @@ def complete_process(request, backend):
         # store last login backend name in session
         request.session[SOCIAL_AUTH_LAST_LOGIN] = social_user.provider
     else:
-        url = getattr(settings, 'LOGIN_ERROR_URL', settings.LOGIN_URL)
+        url = LOGIN_ERROR_URL
     return HttpResponseRedirect(url)
 
 
 @login_required
 def associate(request, backend):
     """Authentication starting process"""
-    complete_url = getattr(settings, 'SOCIAL_AUTH_ASSOCIATE_URL_NAME',
-                           'associate_complete')
-    return auth_process(request, backend, complete_url)
+    return auth_process(request, backend, ASSOCIATE_URL_NAME)
 
 
 @login_required
@@ -93,12 +95,12 @@ def associate_complete(request, backend):
 
 
 @login_required
-def disconnect(request, backend):
+def disconnect(request, backend, association_id=None):
     """Disconnects given backend from current logged in user."""
     backend = get_backend(backend, request, request.path)
     if not backend:
         return HttpResponseServerError('Incorrect authentication service')
-    backend.disconnect(request.user)
+    backend.disconnect(request.user, association_id)
     url = request.REQUEST.get(REDIRECT_FIELD_NAME, '') or DEFAULT_REDIRECT
     return HttpResponseRedirect(url)
 
